/*
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.google.android.samples.socialite.ui.home.settings

import android.content.Context
import android.widget.Toast
import androidx.core.performance.DevicePerformance
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.google.android.samples.socialite.data.DatabaseManager
import com.google.android.samples.socialite.repository.ChatRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import dagger.hilt.android.qualifiers.ApplicationContext
import javax.inject.Inject
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext

@HiltViewModel
class SettingsViewModel @Inject constructor(
    @ApplicationContext private val application: Context,
    private val repository: ChatRepository,
    private val databaseManager: DatabaseManager,
    devicePerformance: DevicePerformance,
) : ViewModel() {
    val mediaPerformanceClass = devicePerformance.mediaPerformanceClass

    fun clearMessages() {
        viewModelScope.launch {
            repository.clearMessages()
            withContext(Dispatchers.IO) {
                databaseManager.wipeAndReinitializeDatabase()
            }
            Toast.makeText(
                application.applicationContext,
                "Messages have been reset",
                Toast.LENGTH_SHORT,
            ).show()
        }
    }

    val isBotEnabledFlow = repository.isBotEnabled

    fun toggleChatbot() {
        viewModelScope.launch {
            repository.toggleChatbotSetting()
        }
    }
}
